@@ -13,51 +13,48 @@
 // Qt models on top of the KEduVocDocument
 #include "containermodel.h"
 #include "lessonmodel.h"
-#include "vocabularymodel.h"
 #include "vocabularyfilter.h"
+#include "vocabularymodel.h"
 #include "wordclassmodel.h"
 
 // Views
-#include "vocabularyview.h"
 #include "containerview.h"
 #include "lessonview.h"
+#include "vocabularyview.h"
 #include "wordtypeview.h"
 
-#include "multiplechoicewidget.h"
-#include "comparisonwidget.h"
-#include "inflectionwidget.h"
-#include "imagechooserwidget.h"
 #include "audiowidget.h"
 #include "browserwidget.h"
-#include "synonymwidget.h"
-#include "summarywordwidget.h"
+#include "comparisonwidget.h"
+#include "imagechooserwidget.h"
+#include "inflectionwidget.h"
 #include "latexwidget.h"
-
-#include "settings/parleyprefs.h"
-#include "prefs.h"
-
-#include "scripts/scriptdialog.h"
-#include "scripts/translator.h"
-
+#include "multiplechoicewidget.h"
 #include "parleyactions.h"
 #include "parleyadaptor.h"
+#include "parleymainwindow.h"
+#include "prefs.h"
+#include "settings/parleyprefs.h"
+#include "summarywordwidget.h"
+#include "synonymwidget.h"
 
 #include <KActionCollection>
-#include <KToggleAction>
 #include <KActionMenu>
 #include <KCharSelect>
+#include <KToggleAction>
 
-#include <QTimer>
 #include <QDockWidget>
 #include <QHeaderView>
 #include <QMenu>
-#include <QStackedWidget>
 #include <QScrollArea>
+#include <QStackedWidget>
+#include <QTimer>
 
 using namespace Editor;
 
-EditorWindow::EditorWindow(ParleyMainWindow* parent)
-    : KXmlGuiWindow(parent), m_mainWindow(parent)
+EditorWindow::EditorWindow(ParleyMainWindow *parent)
+    : KXmlGuiWindow(parent)
+    , m_mainWindow(parent)
 {
     // KXmlGui
     setXMLFile(QStringLiteral("editorui.rc"));
@@ -77,14 +74,10 @@ EditorWindow::EditorWindow(ParleyMainWindow* parent)
     KConfigGroup cfg(KSharedConfig::openConfig(QStringLiteral("parleyrc")), objectName());
     applyMainWindowSettings(cfg);
 
-    connect(parent->parleyDocument(), &ParleyDocument::documentChanged,
-            this,                     &EditorWindow::updateDocument);
-    connect(parent->parleyDocument(), &ParleyDocument::languagesChanged,
-            this,                     &EditorWindow::slotLanguagesChanged);
+    connect(parent->parleyDocument(), &ParleyDocument::documentChanged, this, &EditorWindow::updateDocument);
+    connect(parent->parleyDocument(), &ParleyDocument::languagesChanged, this, &EditorWindow::slotLanguagesChanged);
     connect(parent->parleyDocument(), SIGNAL(statesNeedSaving()), this, SLOT(saveState()));
     connect(parent, &ParleyMainWindow::preferencesChanged, this, &EditorWindow::applyPrefs);
-
-    QTimer::singleShot(0, this, &EditorWindow::initScripts);
 }
 
 EditorWindow::~EditorWindow()
@@ -96,7 +89,6 @@ EditorWindow::~EditorWindow()
 
 void EditorWindow::updateDocument(const std::shared_ptr<KEduVocDocument> &doc)
 {
-
     m_vocabularyView->setDocument(doc);
     m_vocabularyModel->setDocument(doc.get());
 
@@ -109,6 +101,7 @@ void EditorWindow::updateDocument(const std::shared_ptr<KEduVocDocument> &doc)
     m_synonymWidget->setDocument(doc.get());
     m_antonymWidget->setDocument(doc.get());
     m_falseFriendWidget->setDocument(doc.get());
+    m_audioWidget->setDocument(doc.get());
 
     if (!m_mainWindow->parleyDocument()->document()) {
         return;
@@ -122,23 +115,19 @@ void EditorWindow::updateDocument(const std::shared_ptr<KEduVocDocument> &doc)
     m_lessonView->expandToDepth(0);
     m_wordTypeView->expandToDepth(0);
 
-    connect(m_vocabularyView->selectionModel(),
-            &QItemSelectionModel::selectionChanged,
-            m_summaryWordWidget, &SummaryWordWidget::slotSelectionChanged);
-    connect(m_vocabularyView->selectionModel(),
-            &QItemSelectionModel::selectionChanged,
-            m_latexWidget, &LatexWidget::slotSelectionChanged);
+    connect(m_vocabularyView->selectionModel(), &QItemSelectionModel::selectionChanged, m_summaryWordWidget, &SummaryWordWidget::slotSelectionChanged);
+    connect(m_vocabularyView->selectionModel(), &QItemSelectionModel::selectionChanged, m_latexWidget, &LatexWidget::slotSelectionChanged);
 
     m_spellCheckMenu->menu()->clear();
     for (int i = 0; i < doc->identifierCount(); ++i) {
-        QAction* languageSpellCheck = new QAction(doc->identifier(i).name(), m_spellCheckMenu->menu());
+        QAction *languageSpellCheck = new QAction(doc->identifier(i).name(), m_spellCheckMenu->menu());
         m_spellCheckMenu->menu()->addAction(languageSpellCheck);
-        connect(languageSpellCheck, &QAction::triggered,
-                this, [=] {m_vocabularyView->checkSpelling(i);});
+        connect(languageSpellCheck, &QAction::triggered, this, [=] {
+            m_vocabularyView->checkSpelling(i);
+        });
     }
 }
 
-
 void EditorWindow::initDockWidgets()
 {
     // Lesson dockwidget
@@ -152,22 +141,19 @@ void EditorWindow::initDockWidgets()
 
     m_lessonModel = new LessonModel(this);
     m_lessonView->setModel(m_lessonModel);
-    m_lessonView->setToolTip(i18n("Right click to add, delete, or rename units. \n"
-                                  "With the checkboxes you can select which units you want to practice. \n"
-                                  "Only checked units [x] will be asked in the practice!"));
+    m_lessonView->setToolTip(
+        i18n("Right click to add, delete, or rename units. \n"
+             "With the checkboxes you can select which units you want to practice. \n"
+             "Only checked units [x] will be asked in the practice!"));
 
-    connect(m_lessonView, &LessonView::selectedLessonChanged,
-            m_vocabularyModel, &VocabularyModel::setLesson);
+    connect(m_lessonView, &LessonView::selectedLessonChanged, m_vocabularyModel, &VocabularyModel::setLesson);
 
-    connect(m_lessonView, &LessonView::signalShowContainer,
-            m_vocabularyModel, &VocabularyModel::showContainer);
-
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_lessonView, &LessonView::setTranslation);
+    connect(m_lessonView, &LessonView::signalShowContainer, m_vocabularyModel, &VocabularyModel::showContainer);
 
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_lessonView, &LessonView::setTranslation);
 
     // Word classes dock widget
-    QDockWidget* wordTypeDockWidget = new QDockWidget(i18n("Word Types"), this);
+    QDockWidget *wordTypeDockWidget = new QDockWidget(i18n("Word Types"), this);
     wordTypeDockWidget->setObjectName(QStringLiteral("WordTypeDock"));
     m_wordTypeView = new WordTypeView(this);
     wordTypeDockWidget->setWidget(m_wordTypeView);
@@ -178,16 +164,15 @@ void EditorWindow::initDockWidgets()
     wordTypeDockWidget->setVisible(false);
     actionCollection()->addAction(QStringLiteral("show_wordtype_dock"), wordTypeDockWidget->toggleViewAction());
 
-///@todo test, should be fixed with the lesson one though
-///@todo remove before release
-//     new ModelTest(m_wordTypeModel, this);
+    ///@todo test, should be fixed with the lesson one though
+    ///@todo remove before release
+    //     new ModelTest(m_wordTypeModel, this);
 
     m_wordTypeView->setModel(m_wordTypeModel);
 
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_wordTypeView, &WordTypeView::setTranslation);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_wordTypeView, &WordTypeView::setTranslation);
 
-// Inflections
+    // Inflections
     QDockWidget *inflectionDock = new QDockWidget(i18n("Inflection (verbs, adjectives, nouns)"), this);
     inflectionDock->setObjectName(QStringLiteral("InflectionDock"));
     m_inflectionWidget = new InflectionWidget(this);
@@ -198,13 +183,11 @@ void EditorWindow::initDockWidgets()
     addDockWidget(Qt::RightDockWidgetArea, inflectionDock);
     m_dockWidgets.append(inflectionDock);
     actionCollection()->addAction(QStringLiteral("show_inflection_dock"), inflectionDock->toggleViewAction());
-    connect(m_mainWindow->parleyDocument(), &ParleyDocument::documentChanged,
-            m_inflectionWidget, &InflectionWidget::setDocument);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_inflectionWidget, &InflectionWidget::setTranslation);
+    connect(m_mainWindow->parleyDocument(), &ParleyDocument::documentChanged, m_inflectionWidget, &InflectionWidget::setDocument);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_inflectionWidget, &InflectionWidget::setTranslation);
 
-// Comparison forms
-    QDockWidget *comparisonDock = new QDockWidget(i18n("Comparison forms"), this);
+    // Comparison forms
+    QDockWidget *comparisonDock = new QDockWidget(i18n("Comparison Forms"), this);
     comparisonDock->setObjectName(QStringLiteral("ComparisonDock"));
     m_comparisonWidget = new ComparisonWidget(this);
     QScrollArea *comparisonScrollArea = new QScrollArea(this);
@@ -215,11 +198,10 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(comparisonDock);
     actionCollection()->addAction(QStringLiteral("show_comparison_dock"), comparisonDock->toggleViewAction());
     comparisonDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_comparisonWidget, &ComparisonWidget::setTranslation);
-    tabifyDockWidget(comparisonDock,inflectionDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_comparisonWidget, &ComparisonWidget::setTranslation);
+    tabifyDockWidget(comparisonDock, inflectionDock);
 
-// Multiple choice
+    // Multiple choice
     QDockWidget *multipleChoiceDock = new QDockWidget(i18n("Multiple Choice"), this);
     multipleChoiceDock->setObjectName(QStringLiteral("MultipleChoiceDock"));
     MultipleChoiceWidget *multipleChoiceWidget = new MultipleChoiceWidget(this);
@@ -231,10 +213,9 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(multipleChoiceDock);
     actionCollection()->addAction(QStringLiteral("show_multiplechoice_dock"), multipleChoiceDock->toggleViewAction());
     multipleChoiceDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            multipleChoiceWidget, &MultipleChoiceWidget::setTranslation);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, multipleChoiceWidget, &MultipleChoiceWidget::setTranslation);
 
-// Synonym (and the same for antonym and false friends)
+    // Synonym (and the same for antonym and false friends)
     QDockWidget *synonymDock = new QDockWidget(i18n("Synonyms"), this);
     synonymDock->setObjectName(QStringLiteral("SynonymDock"));
     m_synonymWidget = new SynonymWidget(SynonymWidget::Synonym, this);
@@ -246,8 +227,7 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(synonymDock);
     actionCollection()->addAction(QStringLiteral("show_synonym_dock"), synonymDock->toggleViewAction());
     synonymDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_synonymWidget, &SynonymWidget::setTranslation);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_synonymWidget, &SynonymWidget::setTranslation);
 
     QDockWidget *antonymDock = new QDockWidget(i18n("Antonyms"), this);
     antonymDock->setObjectName(QStringLiteral("AntonymDock"));
@@ -260,9 +240,8 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(antonymDock);
     actionCollection()->addAction(QStringLiteral("show_antonym_dock"), antonymDock->toggleViewAction());
     antonymDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_antonymWidget, &SynonymWidget::setTranslation);
-    tabifyDockWidget(synonymDock,antonymDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_antonymWidget, &SynonymWidget::setTranslation);
+    tabifyDockWidget(synonymDock, antonymDock);
 
     QDockWidget *falseFriendDock = new QDockWidget(i18n("False Friends"), this);
     falseFriendDock->setObjectName(QStringLiteral("FalseFriendDock"));
@@ -275,14 +254,13 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(falseFriendDock);
     actionCollection()->addAction(QStringLiteral("show_falsefriend_dock"), falseFriendDock->toggleViewAction());
     falseFriendDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_falseFriendWidget, &SynonymWidget::setTranslation);
-    tabifyDockWidget(antonymDock,falseFriendDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_falseFriendWidget, &SynonymWidget::setTranslation);
+    tabifyDockWidget(antonymDock, falseFriendDock);
 
-// Pronunciation symbols - Use KCharSelect
+    // Pronunciation symbols - Use KCharSelect
     QDockWidget *charSelectDock = new QDockWidget(i18n("Phonetic Symbols"), this);
     charSelectDock->setObjectName(QStringLiteral("IPADock"));
-    KCharSelect *charSelectWidget = new KCharSelect(this, 0, KCharSelect::SearchLine | KCharSelect::BlockCombos | KCharSelect::CharacterTable);
+    KCharSelect *charSelectWidget = new KCharSelect(this, nullptr, KCharSelect::SearchLine | KCharSelect::BlockCombos | KCharSelect::CharacterTable);
     charSelectWidget->setCurrentChar(0x0250);
     QScrollArea *charSelectScrollArea = new QScrollArea(this);
     charSelectScrollArea->setWidgetResizable(true);
@@ -294,7 +272,7 @@ void EditorWindow::initDockWidgets()
     charSelectDock->setVisible(false);
     connect(charSelectWidget, &KCharSelect::charSelected, m_vocabularyView, &VocabularyView::appendChar);
 
-// Image
+    // Image
     QDockWidget *imageDock = new QDockWidget(i18n("Image"), this);
     imageDock->setObjectName(QStringLiteral("ImageDock"));
     ImageChooserWidget *imageChooserWidget = new ImageChooserWidget(this);
@@ -306,11 +284,10 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(imageDock);
     actionCollection()->addAction(QStringLiteral("show_image_dock"), imageDock->toggleViewAction());
     imageDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            imageChooserWidget, &ImageChooserWidget::setTranslation);
-    tabifyDockWidget(multipleChoiceDock,imageDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, imageChooserWidget, &ImageChooserWidget::setTranslation);
+    tabifyDockWidget(multipleChoiceDock, imageDock);
 
-// Summary word
+    // Summary word
     QDockWidget *summaryDock = new QDockWidget(i18n("Summary"), this);
     summaryDock->setObjectName(QStringLiteral("SummaryDock"));
     m_summaryWordWidget = new SummaryWordWidget(m_vocabularyFilter, m_mainWindow->parleyDocument()->document(), this);
@@ -322,26 +299,24 @@ void EditorWindow::initDockWidgets()
     actionCollection()->addAction(QStringLiteral("show_summary_dock"), summaryDock->toggleViewAction());
     summaryDock->setVisible(false);
     m_dockWidgets.append(summaryDock);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_summaryWordWidget, &SummaryWordWidget::setTranslation);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_summaryWordWidget, &SummaryWordWidget::setTranslation);
 
-// Sound
+    // Sound
     QDockWidget *audioDock = new QDockWidget(i18n("Sound"), this);
     audioDock->setObjectName(QStringLiteral("AudioDock"));
-    AudioWidget *audioWidget = new AudioWidget(this);
+    m_audioWidget = new AudioWidget(this);
     QScrollArea *audioScrollArea = new QScrollArea(this);
     audioScrollArea->setWidgetResizable(true);
-    audioScrollArea->setWidget(audioWidget);
+    audioScrollArea->setWidget(m_audioWidget);
     audioDock->setWidget(audioScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, audioDock);
     m_dockWidgets.append(audioDock);
     actionCollection()->addAction(QStringLiteral("show_audio_dock"), audioDock->toggleViewAction());
     audioDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            audioWidget, &AudioWidget::setTranslation);
-    tabifyDockWidget(imageDock,audioDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_audioWidget, &AudioWidget::setTranslation);
+    tabifyDockWidget(imageDock, audioDock);
 
-// browser
+    // browser
     QDockWidget *browserDock = new QDockWidget(i18n("Internet"), this);
     browserDock->setObjectName(QStringLiteral("BrowserDock"));
     BrowserWidget *htmlPart = new BrowserWidget(browserDock);
@@ -353,11 +328,10 @@ void EditorWindow::initDockWidgets()
     m_dockWidgets.append(browserDock);
     actionCollection()->addAction(QStringLiteral("show_browser_dock"), browserDock->toggleViewAction());
     browserDock->setVisible(false);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            htmlPart, &BrowserWidget::setTranslation);
-    tabifyDockWidget(summaryDock,browserDock);
+    connect(m_vocabularyView, &VocabularyView::translationChanged, htmlPart, &BrowserWidget::setTranslation);
+    tabifyDockWidget(summaryDock, browserDock);
 
-// LaTeX
+    // LaTeX
     QDockWidget *latexDock = new QDockWidget(i18n("LaTeX"), this);
     latexDock->setObjectName(QStringLiteral("LatexDock"));
     m_latexWidget = new LatexWidget(m_vocabularyFilter, m_mainWindow->parleyDocument()->document().get(), this);
@@ -369,24 +343,22 @@ void EditorWindow::initDockWidgets()
     actionCollection()->addAction(QStringLiteral("show_latex_dock"), latexDock->toggleViewAction());
     latexDock->setVisible(false);
     m_dockWidgets.append(latexDock);
-    connect(m_vocabularyView, &VocabularyView::translationChanged,
-            m_latexWidget, &LatexWidget::setTranslation);
-    tabifyDockWidget(audioDock,latexDock);
-
-// Grades
-//     QDockWidget *gradeDock = new QDockWidget(i18n("Grade"), this);
-//     gradeDock->setObjectName("gradeDock");
-//     QLabel *gradeWidget = new QLabel("grade placeholder", this);
-//     gradeDock->setWidget(gradeWidget);
-//     addDockWidget(Qt::RightDockWidgetArea, gradeDock);
-//     connect(this, SIGNAL(signalSetData(KEduVocTranslation*)), m_declensionWidget, SLOT(setTranslation(KEduVocTranslation*)));
+    connect(m_vocabularyView, &VocabularyView::translationChanged, m_latexWidget, &LatexWidget::setTranslation);
+    tabifyDockWidget(audioDock, latexDock);
 
+    // Grades
+    //     QDockWidget *gradeDock = new QDockWidget(i18n("Grade"), this);
+    //     gradeDock->setObjectName("gradeDock");
+    //     QLabel *gradeWidget = new QLabel("grade placeholder", this);
+    //     gradeDock->setWidget(gradeWidget);
+    //     addDockWidget(Qt::RightDockWidgetArea, gradeDock);
+    //     connect(this, SIGNAL(signalSetData(KEduVocTranslation*)), m_declensionWidget, SLOT(setTranslation(KEduVocTranslation*)));
 }
 
 void EditorWindow::initActions()
 {
     ParleyActions::create(ParleyActions::RemoveGrades, this, SLOT(removeGrades()), actionCollection());
-    m_spellCheckMenu = ParleyActions::create(ParleyActions::CheckSpelling, 0, "", actionCollection());
+    m_spellCheckMenu = ParleyActions::create(ParleyActions::CheckSpelling, nullptr, "", actionCollection());
     m_spellCheckMenu->setMenu(new QMenu(this));
 
     ParleyActions::create(ParleyActions::ToggleShowSublessons, m_vocabularyModel, SLOT(showEntriesOfSubcontainers(bool)), actionCollection());
@@ -397,7 +369,6 @@ void EditorWindow::initActions()
     ParleyActions::create(ParleyActions::ConfigurePractice, m_mainWindow, SLOT(configurePractice()), actionCollection());
     ParleyActions::create(ParleyActions::ToggleSearchBar, this, SLOT(slotConfigShowSearch()), actionCollection());
     ParleyActions::create(ParleyActions::SearchVocabulary, this, SLOT(startSearch()), actionCollection());
-    ParleyActions::create(ParleyActions::ShowScriptManager, this, SLOT(slotShowScriptManager()), actionCollection());
     ParleyActions::create(ParleyActions::LanguagesProperties, m_mainWindow->parleyDocument(), SLOT(languageProperties()), actionCollection());
 
     new EditorWindowAdaptor(this);
@@ -420,8 +391,8 @@ void EditorWindow::initModel()
     m_vocabularyFilter->setSourceModel(m_vocabularyModel);
     m_vocabularyView->setFilter(m_vocabularyFilter);
 
-//    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyModel, SLOT(setDocument(KEduVocDocument*)));
-//    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyView, SLOT(setDocument(KEduVocDocument*)));
+    //    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyModel, SLOT(setDocument(KEduVocDocument*)));
+    //    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyView, SLOT(setDocument(KEduVocDocument*)));
     connect(m_searchLine, &QLineEdit::textChanged, m_vocabularyFilter, &VocabularyFilter::setSearchString);
 }
 
@@ -446,13 +417,13 @@ void EditorWindow::initView()
     label->show();
 
     m_searchWidget = new QWidget(this);
-    QHBoxLayout* layout = new QHBoxLayout(m_searchWidget);
+    QHBoxLayout *layout = new QHBoxLayout(m_searchWidget);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(label);
     layout->addWidget(m_searchLine);
 
-///@todo     centralWidget()-> delete layout
-    QVBoxLayout * rightLayout = new QVBoxLayout();
+    ///@todo     centralWidget()-> delete layout
+    QVBoxLayout *rightLayout = new QVBoxLayout();
     rightLayout->setContentsMargins(0, 0, 0, 0);
     rightLayout->addWidget(m_searchWidget);
     m_searchWidget->setVisible(Prefs::showSearch());
@@ -475,13 +446,6 @@ void EditorWindow::startSearch()
     m_searchLine->setFocus();
 }
 
-void EditorWindow::slotShowScriptManager()
-{
-    ScriptDialog * dialog = new ScriptDialog(m_scriptManager);
-    dialog->setAttribute(Qt::WA_DeleteOnClose);
-    dialog->show();
-}
-
 void EditorWindow::applyPrefs()
 {
     m_vocabularyView->reset();
@@ -492,16 +456,6 @@ void EditorWindow::removeGrades()
     m_mainWindow->parleyDocument()->document()->lesson()->resetGrades(-1, KEduVocContainer::Recursive);
 }
 
-void EditorWindow::initScripts()
-{
-    m_scriptManager = new ScriptManager(this);
-
-    m_vocabularyView->setTranslator(m_scriptManager->translator());
-
-    //Load scripts
-    m_scriptManager->loadScripts();
-}
-
 void EditorWindow::saveState()
 {
     m_vocabularyView->saveColumnVisibility();
@@ -511,3 +465,5 @@ void EditorWindow::slotLanguagesChanged()
 {
     m_vocabularyModel->resetLanguages();
 }
+
+#include "moc_editor.cpp"
