@@ -156,7 +156,7 @@ void LessonView::setTranslation(KEduVocExpression *entry, int translation)
 {
     Q_UNUSED(translation)
 
-    if (entry == 0) {
+    if (entry == nullptr) {
         selectionModel()->clearSelection();
         return;
     }
@@ -288,3 +288,5 @@ void LessonView::collapseAllLesson()
 {
     collapseAll();
 }
+
+#include "moc_lessonview.cpp"
